@@ -1,29 +1,29 @@
 from __future__ import annotations
 
 import math
-from typing import List
+from typing import List, Union
 
 from violetear.types import GridTemplate
 
 
 def px(x: int):
-    return Unit(x, "px")
+    return Unit(int(x), "px")
 
 
 def pt(x: float):
-    return Unit(x, "pt")
+    return Unit(round(x, 3), "pt")
 
 
 def em(x: float):
-    return Unit(x, "em")
+    return Unit(round(x, 3), "em")
 
 
 def rem(x: float):
-    return Unit(x, "rem")
+    return Unit(round(x, 3), "rem")
 
 
 def fr(x: float):
-    return Unit(x, "fr")
+    return Unit(round(x, 2), "fr")
 
 
 def pc(x: float):
@@ -35,7 +35,7 @@ def sec(x: float):
 
 
 def ms(x: int):
-    return Unit(x, "ms")
+    return Unit(int(x), "ms")
 
 
 class Unit:
@@ -46,6 +46,12 @@ class Unit:
     def __str__(self):
         return f"{self.value}{self.unit}"
 
+    def __mul__(self, other: Union[int, float]):
+        return Unit(self.value * other, self.unit)
+
+    def __truediv__(self, other: Union[int, float]):
+        return Unit(self.value / other, self.unit)
+
     @staticmethod
     def infer(x, on_float=rem, on_int=px):
         if isinstance(x, int):
